TextFSM.Template.Compiler (TextFSM v0.1.2)

Copy Markdown View Source

Compiles a parsed TextFSM template.

The compilation process involves:

  1. Inlining value descriptors to their regex patterns in the rules of each state.
  2. Compiling the final string regular expressions into Regex structs.

Summary

Functions

Compiles the given template.

Functions

compile(template, modifiers \\ "")

Compiles the given template.

Parameters

Returns