TextFSM.Template.State (TextFSM v0.1.2)

Copy Markdown View Source

Represents a State in a TextFSM template.

A State is a named collection of Rules. The Engine starts in the 'Start' state. Each line of input is matched against the rules in the current state.

Summary

Types

t()

@type t() :: %TextFSM.Template.State{
  name: String.t(),
  rules: [TextFSM.Template.State.Rule.t()]
}

Functions

state(binary, opts \\ [])

@spec state(binary(), keyword()) ::
  {:ok, [term()], rest, context, line, byte_offset}
  | {:error, reason, rest, context, line, byte_offset}
when line: {pos_integer(), byte_offset},
     byte_offset: non_neg_integer(),
     rest: binary(),
     reason: String.t(),
     context: map()

Parses the given binary as state.

Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the state (start position) as {line, offset_to_start_of_line}.

To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.

Options

  • :byte_offset - the byte offset for the whole binary, defaults to 0
  • :line - the line and the byte offset into that line, defaults to {1, byte_offset}
  • :context - the initial context value. It will be converted to a map

state__0(rest, acc, stack, context, line, offset)

state__1(rest, acc, stack, context, line, offset)

state__2(rest, acc, stack, context, line, offset)

state__3(rest, user_acc, list, context, line, offset)

state__4(rest, acc, stack, context, line, offset)

state__5(rest, acc, stack, context, line, offset)

state__6(_, _, list, _, _, _)

state__7(rest, acc, stack, context, line, offset)

state__8(rest, acc, stack, context, line, offset)

state__9(rest, acc, stack, context, line, offset)

state__10(rest, acc, stack, context, line, offset)

state__11(rest, user_acc, list, context, line, offset)

state__12(rest, acc, stack, context, line, offset)

state__13(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)

state__14(rest, user_acc, list, context, line, offset)

state__15(rest, user_acc, list, context, line, offset)

state__16(rest, acc, stack, context, line, offset)