TextFSM.Template.State.Rule (TextFSM v0.1.2)

Copy Markdown View Source

Summary

Types

regex_token()

@type regex_token() :: char() | value_descriptor()

t()

@type t() :: %TextFSM.Template.State.Rule{
  action:
    TextFSM.Template.State.Rule.Action.t()
    | TextFSM.Template.State.Rule.ErrorAction.t(),
  compiled_regex: Regex.t(),
  regex_tokens: []
}

value_descriptor()

@type value_descriptor() :: {:value_descriptor, String.t()}

Functions

rule(binary, opts \\ [])

@spec rule(binary(), keyword()) ::
  {:ok, [term()], rest, context, line, byte_offset}
  | {:error, reason, rest, context, line, byte_offset}
when line: {pos_integer(), byte_offset},
     byte_offset: non_neg_integer(),
     rest: binary(),
     reason: String.t(),
     context: map()

Parses the given binary as rule.

Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the rule (start position) as {line, offset_to_start_of_line}.

To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.

Options

  • :byte_offset - the byte offset for the whole binary, defaults to 0
  • :line - the line and the byte offset into that line, defaults to {1, byte_offset}
  • :context - the initial context value. It will be converted to a map

rule__0(rest, acc, stack, context, line, offset)

rule__1(rest, acc, stack, context, comb__line, comb__offset)

rule__2(rest, acc, stack, context, line, offset)

rule__3(rest, acc, stack, context, line, offset)

rule__4(_, _, list, _, _, _)

rule__5(rest, acc, stack, context, line, offset)

rule__6(rest, acc, stack, context, line, offset)

rule__7(_, _, list, _, _, _)

rule__8(_, _, list, _, _, _)

rule__9(rest, acc, stack, context, line, offset)

rule__10(inner_rest, inner_acc, list, inner_context, inner_line, inner_offset)

rule__11(rest, user_acc, list, context, line, offset)

rule__12(rest, acc, stack, context, line, offset)

rule__13(rest, acc, stack, context, line, offset)

rule__14(rest, user_acc, list, context, line, offset)

rule__15(rest, acc, list, context, line, offset)

rule__16(_, _, stack, _, _, _)

rule__17(rest, acc, stack, context, line, offset)

rule__18(rest, acc, list, context, line, offset)

rule__19(rest, user_acc, list, context, line, offset)

rule__20(rest, acc, stack, context, line, offset)