TextFSM.Template.State.Rule.Action (TextFSM v0.1.2)

Copy Markdown View Source

Summary

Types

line_action()

@type line_action() :: :next | :continue

record_action()

@type record_action() :: :no_record | :record | :clear | :clear_all

t()

@type t() :: %TextFSM.Template.State.Rule.Action{
  line_action: line_action(),
  next_state: String.t(),
  record_action: record_action()
}

Functions

rule_action(binary, opts \\ [])

@spec rule_action(binary(), keyword()) ::
  {:ok, [term()], rest, context, line, byte_offset}
  | {:error, reason, rest, context, line, byte_offset}
when line: {pos_integer(), byte_offset},
     byte_offset: non_neg_integer(),
     rest: binary(),
     reason: String.t(),
     context: map()

Parses the given binary as rule_action.

Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the rule_action (start position) as {line, offset_to_start_of_line}.

To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.

Options

  • :byte_offset - the byte offset for the whole binary, defaults to 0
  • :line - the line and the byte offset into that line, defaults to {1, byte_offset}
  • :context - the initial context value. It will be converted to a map

rule_action__0(rest, acc, stack, context, line, offset)

rule_action__1(rest, acc, stack, context, line, offset)

rule_action__2(rest, user_acc, list, context, line, offset)

rule_action__3(rest, acc, stack, context, line, offset)

rule_action__4(rest, acc, stack, context, line, offset)

rule_action__5(rest, user_acc, list, context, line, offset)

rule_action__6(rest, acc, list, context, line, offset)

rule_action__7(_, _, stack, _, _, _)

rule_action__8(rest, acc, stack, context, line, offset)

rule_action__9(rest, acc, list, context, line, offset)

rule_action__10(_, _, stack, _, _, _)

rule_action__11(rest, acc, stack, context, line, offset)

rule_action__12(rest, acc, stack, context, line, offset)

rule_action__13(rest, acc, stack, context, line, offset)

rule_action__14(rest, acc, stack, context, line, offset)

rule_action__15(rest, user_acc, list, context, line, offset)

rule_action__16(rest, acc, list, context, line, offset)

rule_action__17(rest, acc, stack, context, line, offset)